@@ -16,14 +16,13 @@ fn pre_format(line: &str, row: usize, input: tree_sitter::Node) -> String {
         .map(|(i, _)| i)
         .collect();
     for column in comment_chars {
-        if column == 0 {
-            continue;
-        }
-        if (is_comment(tree_sitter::Point { row, column }, input)
+        if is_comment(tree_sitter::Point { row, column }, input)
             // this means it is the extra line, so should think it should be comment line
-            || (row == input.end_position().row && column >= input.end_position().column))
-            && line.chars().nth(column - 1).unwrap() != ' '
+            || (row == input.end_position().row && column >= input.end_position().column)
         {
+            if column == 0 || line.chars().nth(column - 1).unwrap() == ' ' {
+                break;
+            }
             let linebefore = &line[..column];
             let lineafter = &line[column..];
             return format!("{linebefore} {lineafter}");
